# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Action Box
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent

from BaseTemplet import BaseTemplet


def addActionBox(dispatcher, id, REQUEST=None, **kw):
    """Add an Action Box Templet."""
    ob = ActionBox(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Action Box Templet',
     'title': 'Action Box',
     'description': ('a box containing individual action buttons'),
     'meta_type': 'Action Box Templet',
     'icon': 'actionbox_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addActionBox',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions':  BaseTemplet._actions +
                 (
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_actionbox',
                  'visible': 0,
                  'permissions': (View,)},
                 ),
     },
    )


class ActionBox(BaseTemplet):
    """
    Action Box Templet.
    """

    meta_type = 'Action Box Templet'
    portal_type = 'Action Box Templet'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
        {'id': 'actions_to_display', 
         'type': 'multiple selection', 
         'mode': 'w', 
         'label': 'Action categories',  
         'select_variable': 'cpsskins_listActions', 
         'category': 'general'},
        {'id': 'style', 
         'type': 'selection', 
         'mode': 'w', 
         'label': 'Appearance', 
         'select_variable': 'cpsskins_actionbox_styleList', 
         'category' : 'style'},
        {'id': 'orientation', 
         'type': 'selection', 
         'mode': 'w', 
         'label': 'Box orientation', 
         'select_variable': 'cpsskins_orientationList', 
         'category' : 'style'},
        {'id': 'icon_size', 
         'type': 'selection', 
         'mode': 'w', 
         'label': 'Icon size',  
         'select_variable': 'cpsskins_iconsizeList', 
         'category': 'style'}
        )

    def __init__(self, id, 
                       style='text and icons', 
		       actions_to_display=['login', 'logout', 'globalboxes', 'configThemes',],  
		       icon_size='16x16',  
                       orientation = 'horizontal',
		       **kw):
        apply(BaseTemplet.__init__, (self, id), kw)
        self.actions_to_display = actions_to_display
        self.style = style
        self.orientation = orientation
        self.icon_size = icon_size

InitializeClass(ActionBox)

