# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Area Color
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent


from BaseStyle import BaseStyle


def addAreaColor(dispatcher, id, REQUEST=None, **kw):
    """Add an Area Color."""
    ob = AreaColor(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Area Color',
     'title': 'Area Color',
     'description': ('Area Color'),
     'meta_type': 'Area Color',
     'icon': 'area_color.gif',
     'product': 'CPSSkins',
     'factory': 'addAreaColor',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions': BaseStyle._actions +
                (
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_areacolor',
                  'visible': 0,
                  'permissions': (View,)},
                 {'id': 'preview',
                  'name': 'Preview',
                  'action': 'cpsskins_areacolor_preview',
                  'visible': 0,
                  'permissions': (View,)
		 },
                 {'id': 'list',
                  'name': 'List',
                  'action': 'cpsskins_listAreaColors',
                  'visible': 0,
                  'permissions': (View,)
		 },
                 ),
     },
    )


class AreaColor(BaseStyle):
    """
    Area Color.
    """

    meta_type = 'Area Color'
    portal_type = 'Area Color'

    security = ClassSecurityInfo()

    _properties = BaseStyle._properties + (
        {'id': 'Area_border_color', 
         'type': 'string', 
         'mode': 'w', 
         'label': 'Area border color', 
         'palette' : 'Palette Color'},
        {'id': 'Area_bg_color', 
         'type': 'string', 
         'mode': 'w', 
         'label': 'Area background color', 
         'palette' : 'Palette Color'},
        {'id': 'Area_bg_image', 
         'type': 'selection', 
         'mode': 'w', 
         'label': 'Area background image', 
         'select_variable' : 'cpsskins_listBackgrounds', 
         'image': 'backgrounds'},
        {'id': 'Area_font_color', 
         'type': 'string', 
         'mode': 'w', 
         'label': 'Area font color', 
         'palette' : 'Palette Color'},
        )

    def __init__(self, id, 
                       Area_border_color = '#CCCCCC',
                       Area_bg_color = '#FFFFFF',
                       Area_bg_image = '',
                       Area_font_color = '#000000',
		       **kw):
        apply(BaseStyle.__init__, (self, id), kw)
	self.Area_border_color = Area_border_color
	self.Area_bg_color = Area_bg_color
	self.Area_bg_image = Area_bg_image
	self.Area_font_color = Area_font_color

InitializeClass(AreaColor)

