# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Base Cell Modifier
"""

from zLOG import LOG, INFO
import string

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from OFS.PropertyManager import PropertyManager
from Acquisition import aq_base, aq_parent
from Products.CMFCore.utils import _verifyActionPermissions, getToolByName
from Products.CMFCore.CMFCorePermissions import View
from Products.CMFCore.PortalContent import PortalContent

from Products.CPSSkins.PortalThemesTool import PortalThemesTool

def addBaseCellModifier(dispatcher, id, REQUEST=None):
    """Add a Base Cell Modifier."""
    ob = BaseCellModifier(id)
    container = dispatcher.Destination()
    container._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Base Cell Modifier',
     'description': ('A Base Cell Modifier is the most basic cell modifier.'),
     'meta_type': 'Base CellModifier',
     'icon': 'skinner_icon.gif',
     'product': 'CPSSkins',
     'factory': 'addBaseCellModifier',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'actions':  (
                 {'id': 'view',
                  'name': 'View',
                  'action': 'cpsskins_default_view',
                  'permissions': (View,)},
                 {'id': 'edit',
                  'name': 'Edit',
                  'action': 'cpsskins_edit_form',
                  'permissions': ('Manage Themes',)},
                 {'id': 'delete',
                  'name': 'Delete',
                  'action': 'cpsskins_object_delete',
                  'visible': 0,
                  'permissions': ('Manage Themes',)},
                 ),
     },
    )


class BaseCellModifier(PortalContent, PropertyManager):
    """
    Base class for cell modifiers.
    """

    meta_type = None
    portal_type = None

    manage_options = ( PropertyManager.manage_options     # Properties
                     )

    security = ClassSecurityInfo()

    _actions = factory_type_information[0]['actions']

    _properties = (
        {'id': 'xpos', 
         'type': 'int', 
         'mode': 'w', 
         'label': 'Xpos', 
         'category': 'none'},
        )


    def __init__(self, id, 
                       xpos = int(0), 
                       **kw):
        self.id = id
        self.xpos = xpos

 
    security.declareProtected(View,'isCellModifier')
    def isCellModifier(self):
           
        return 1

    security.declareProtected(View,'isPortalContent')
    def isPortalContent(self):
        """ is portal content """
           
        return 0

    security.declarePublic('getIconRelative')
    def getIconRelative(self):
        """
        Gets the Icon path, relative to the portal.
        This is needed to catalog correctly in the presence of VHM.
        """
        return self.getIcon(1)

    security.declareProtected('Manage Themes', 'rebuild')
    def rebuild(self):
        """                  
        Rebuild this theme
        """              
                         
        for pm in self.propertyMap():
            for p in self._properties:
                 if p['id'] == pm['id']:
                     for k in pm.keys():
                         p[k] = pm.get(k, None)
                             
        prop_dict = {}       
        ids =  self.propertyIds()
        for id in ids:       
           try:              
               prop = self.getProperty(id)
           except:           
               prop = None   
           prop_dict[id] = prop
                             
        self.manage_delProperties(ids, REQUEST=None)
        self.manage_changeProperties(prop_dict)

    security.declarePrivate('callAction')
    def callAction(self, actionid, **kw):
        """
        Call the given action.
        """

        ti = self.getTypeInfo() 
        try: 
             action = ti.getActionById(actionid)
        except:
             return 
        else:
          meth = self.restrictedTraverse(action)

          # XXX Check permissions

          if getattr(aq_base(meth), 'isDocTemp', 0):
                return apply(meth, (self, self.REQUEST), kw)
          else:
                return apply(meth, (), kw)
          raise 'Not Found', (
            'Cannot find %s action for "%s"' %
            (actionid, self.absolute_url(relative=1)))


    security.declareProtected(View, 'edit_form')
    def edit_form(self, **kw):
        """
        Call the edit action.
        """
        return self.callAction('edit', **kw)

    security.declareProtected('Manage Themes', 'edit')
    def edit(self, **kw):
        """
        Default edit method, changes the properties.
        """
        self.manage_changeProperties(**kw)


    security.declarePublic('getInfo')
    def getInfo(self):

        infoblock = {}
        actions_list = ['delete', 'edit']

        ti = self.getTypeInfo()
        for actionid in actions_list:  
             actioninfo = {}
             if actionid == 'delete':
                 actioninfo['can_delete'] = self.can_delete()
             try:
                action = ti.getActionById(actionid)
                actioninfo['url']  = self.absolute_url() + '/' + self.restrictedTraverse(action).getId()
             except:
                continue
             infoblock[actionid] = actioninfo

                            
        return infoblock


    security.declareProtected(View, 'can_delete')
    def can_delete(self):
        """ Can the cell sizer be deleted ?
        """
           
        return 1


InitializeClass(BaseCellModifier)


