# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Breadcrumbs Templet
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent


from BaseTemplet import BaseTemplet


def addBreadcrumbs(dispatcher, id, REQUEST=None, **kw):
    """Add a Breadcrumbs Templet."""
    ob = Breadcrumbs(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Breadcrumbs Templet',
     'title': 'Breadcrumbs',
     'description': ('a navigation trail from the current folder'),
     'meta_type': 'Breadcrumbs Templet',
     'icon': 'breadcrumbs_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addBreadcrumbs',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions':  BaseTemplet._actions + 
                 (
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_breadcrumbs',
                  'visible': 0,
                  'permissions': (View,)
                 },
                 ),
     },
    )


class Breadcrumbs(BaseTemplet):
    """
    Breadcrumbs Templet.
    """
    meta_type = 'Breadcrumbs Templet'
    portal_type = 'Breadcrumbs Templet'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
        {'id': 'separator_start', 
         'type': 'string', 
         'mode': 'w', 
         'label': 'Start string'},
        {'id': 'separator_repeat', 
         'type': 'string', 
         'mode': 'w', 
         'label': 'Repeat string'},
        {'id': 'separator_end', 
         'type': 'string', 
         'mode': 'w', 
         'label': 'End string'},
        )

    def __init__(self, id, 
                       separator_start = 'You are here:',
                       separator_repeat = '&raquo;',
                       separator_end = '',
		       **kw):
        apply(BaseTemplet.__init__, (self, id), kw)
        self.separator_start = separator_start
        self.separator_repeat = separator_repeat
        self.separator_end = separator_end


InitializeClass(Breadcrumbs)

