# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Cell Hider
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from Acquisition import aq_base, aq_parent, aq_inner

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent, ManagePortal
from Products.CMFCore.utils import _checkPermission, _verifyActionPermissions
from Products.CMFCore.utils import getToolByName

from BaseCellModifier import BaseCellModifier


def addCellHider(dispatcher, id, REQUEST=None, **kw):
    """Add a Cell Hider."""
    ob = CellHider(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Cell Hider',
     'title': 'Cell Hider',
     'description': ('Cell Hider'),
     'meta_type': 'Cell Hider',
     'icon': 'cell_hider.gif',
     'product': 'CPSSkins',
     'factory': 'addCellHider',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions': BaseCellModifier._actions + 
                 (
                 ),
     },
    )


class CellHider(BaseCellModifier):
    """
    Cell Hider.
    """
    meta_type = 'Cell Hider'
    portal_type = 'Cell Hider'

    security = ClassSecurityInfo()


    _properties = BaseCellModifier._properties + (
        {'id': 'visibility', 'type': 'selection', 'mode': 'w', 'label': 'Visibility criteria', 'select_variable' : 'cpsskins_visibilityList', 'category' : 'visibility'},
        {'id': 'visibility_paths', 'type': 'multiple selection', 'mode':'w', 'label':'The visibility paths', 'select_variable' : 'cpsskins_listPaths', 'category' : 'visibility'},
        {'id': 'languages', 'type': 'multiple selection', 'mode':'w', 'label':'The languages in which it is visible', 'select_variable' : 'cpsskins_listLanguages', 'category' : 'visibility'},

        )

    def __init__(self, id, 
                       visibility = 'always',
                       visibility_paths= [],
                       languages = [],
		       **kw):
        apply(BaseCellModifier.__init__, (self, id), kw)
        self.visibility = visibility
        self.visibility_paths = visibility_paths
        self.languages = languages


    security.declareProtected(View,'isCellHider')
    def isCellHider(self):
           
        return 1


    security.declarePublic('getVisibility')
    def getVisibility(self, REQUEST=None):

        if self.languages:
            portal = getToolByName(self, 'portal_url').getPortalObject()
            if hasattr(portal, 'Localizer'):
                lctool = portal.Localizer
            else:
                lctool = getToolByName(self, 'portal_messages')
            if lctool is None:
                return 0
            selected_language = lctool.get_selected_language()
            lang_list = self.languages

            if selected_language not in lang_list:
                return 0

        visibility = self.visibility
        if visibility == 'always':
            return 1

        if visibility == 'time_limited':
            now = DateTime()
            effective_date = self.EffectiveDate()
            expiration_date = self.ExpirationDate()

            if effective_date != 'None':
               if now < DateTime(effective_date):
                  return 0

            if expiration_date != 'None':
               if now >= DateTime(expiration_date):
                  return 0
            return 1

        if visibility == 'if_authenticated':
            mtool = getToolByName(self, 'portal_membership')
            if not mtool.isAnonymousUser():
                return 1       
                               
        if visibility == 'if_anonymous':
            mtool = getToolByName(self, 'portal_membership')
            if mtool.isAnonymousUser():
                return 1       
                               
        if visibility in ['only_in', 'everywhere_except_in', 'starting_from', 'up_till']:
            utool = getToolByName(self, 'portal_url')
            portal_url = utool(relative=0)
                               
            if REQUEST is None:
                return 0      
                              
            # simulated URL
            rurl = REQUEST.form.get('sim_url', None)
            if rurl:           
               url =  portal_url + rurl
                               
            # real URL         
            if rurl is None:
               url_obj = REQUEST.get('context_obj', None)
               if url_obj:     
                    url = utool.getRelativeContentURL(url_obj)  
                    if url:    
                        url = '/' + url + '/'
                    else:      
                        url = '/'
                               
            if url is None:    
               return 0   
                          
            url_path = url
                         
            paths = [(p == '/' and '' or p) for p in self.visibility_paths]
                               
            if visibility == 'only_in':
                if url_path in paths:
                      return 1 
                               
            if visibility == 'everywhere_except_in':
                if url_path not in paths:
                      return 1 
                               
            if visibility == 'starting_from':
               for p in paths: 
                   if url_path.startswith(p):
                      return 1 
                               
            if visibility == 'up_till':
               for p in paths: 
                   if url_path.startswith(p) and url_path != p:
                      return 0 
               return 1        
                             
                      
        if visibility == 'if_secure_connection':
            if REQUEST is not None:
                theBase = REQUEST['BASE0'].split('//')[0]
                if theBase == 'https:': 
                    return 1   




InitializeClass(CellHider)

