# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Cell Sizer
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo
from Acquisition import aq_base, aq_parent, aq_inner

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent, ManagePortal
from Products.CMFCore.utils import _checkPermission, _verifyActionPermissions

from BaseCellModifier import BaseCellModifier


def addCellSizer(dispatcher, id, REQUEST=None, **kw):
    """Add a Cell Sizer."""
    ob = CellSizer(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Cell Sizer',
     'title': 'Cell Sizer',
     'description': ('Cell Sizer'),
     'meta_type': 'Cell Sizer',
     'icon': 'cell_sizer.gif',
     'product': 'CPSSkins',
     'factory': 'addCellSizer',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions': BaseCellModifier._actions + 
                 (
                 ),
     },
    )


class CellSizer(BaseCellModifier):
    """
    Cell Sizer.
    """
    meta_type = 'Cell Sizer'
    portal_type = 'Cell Sizer'

    security = ClassSecurityInfo()


    _properties = BaseCellModifier._properties + (
        {'id': 'cellwidth', 'type': 'string', 'mode': 'w', 'label': 'Cell width'},
        )

    def __init__(self, id, 
                       cellwidth = '25%', 
		       **kw):
        apply(BaseCellModifier.__init__, (self, id), kw)
        self.cellwidth = cellwidth


    security.declareProtected(View,'isCellSizer')
    def isCellSizer(self):
           
        return 1

InitializeClass(CellSizer)

