# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Cell Styler
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent


from BaseCellModifier import BaseCellModifier


def addCellStyler(dispatcher, id, REQUEST=None, **kw):
    """Add a Cell Styler."""
    ob = CellStyler(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Cell Styler',
     'title': 'Cell Styler',
     'description': ('Cell Styler'),
     'meta_type': 'Cell Styler',
     'icon': 'cell_styler.gif',
     'product': 'CPSSkins',
     'factory': 'addCellStyler',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions': BaseCellModifier._actions + 
                 (
                 ),
     },
    )


class CellStyler(BaseCellModifier):
    """
    Cell Styler.
    """
    meta_type = 'Cell Styler'
    portal_type = 'Cell Styler'

    security = ClassSecurityInfo()


    _properties = BaseCellModifier._properties + (
        {'id': 'shape', 'type': 'selection', 'mode': 'w', 'label': 'Shape', 'select_variable': 'cpsskins_listAreaShapes'},
        {'id': 'color', 'type': 'selection', 'mode': 'w', 'label': 'Color', 'select_variable': 'cpsskins_listAreaColors'},
        )

    def __init__(self, id, 
                       shape = 'NoBorder', 
                       color = 'Transparent', 
		       **kw):
        apply(BaseCellModifier.__init__, (self, id), kw)
        self.shape = shape
        self.color = color


    security.declareProtected(View,'isCellStyler')
    def isCellStyler(self):
           
        return 1



InitializeClass(CellStyler)

