import os
import sys
from App.Extensions import getPath
from Products.CMFCore.ActionInformation import ActionInformation
from Products.CMFCore.Expression import Expression
from Products.CMFCore.utils import getToolByName
from Products.CMFCore.CMFCorePermissions import setDefaultRoles
from re import match
from ExtensionClass import Base
from Products.StandardCacheManagers.RAMCacheManager import RAMCacheManager
from Products.ExternalMethod.ExternalMethod import ExternalMethod

import zLOG

def package_home(name):
    """Returns path to Products.name"""
    m = sys.modules['Products.%s' % name]
    return (m.__path__[0])

cpsskins_home = package_home('CPSSkins')
zexpdir = os.path.join(cpsskins_home, 'Install')
                                           
def logf(summary,message='',severity=0):
  summary = '['+ str(summary) +']'
  if message:
    message = str(message)+'\n'
  zLOG.LOG('CPSSkins: ',severity,summary, message)

def setperms(object, perms, pr=None):
    for perm, roles in perms.items():
        acquire = type(roles) == type([])
        object.manage_permission(perm, roles, acquire)
        pr("  Permission %s" % perm)

def install(self, SourceSkin=None, Target=None, ReinstallDefaultThemes=None, EnableTempletCache=None):

    if Target is None:
       return

    logf("START: CPSSkins install")
    log = []
    pr = log.append

    def pr_h3(msg, pr=pr):
        pr('<h3>%s</h3>' % msg)

    def prok(pr=pr):
        pr(" Already correctly installed")

    portal = self.portal_url.getPortalObject()
    skinstool = getToolByName(self, 'portal_skins')

    def portalhas(id, portal=portal):
        return id in portal.objectIds()

    pr("<pre>")
    pr("Starting CPSSkins install")


    pr_h3("Dependencies")
    try:
       import Products.TranslationService
       translationservice_is_present = 1
       pr("TranslationService is installed")
    except ImportError:
       translationservice_is_present = 0
       pr("TranslationService is not installed")

    try:
       import Products.Localizer
       localizer_is_present = 1
       pr("Localizer is installed")
    except ImportError:
       localizer_is_present = 0
       pr("Localizer is not installed")


    pr_h3("i18n")
    mcat = None
    if Target == 'CPS2':

        if portalhas('Localizer'):
           portal.manage_delObjects(['Localizer'])


    if Target in ['CMF', 'CPS3', 'Plone', 'Plone2' ]:

      # Localizer
      if localizer_is_present:
        if not portalhas('Localizer'):
          pr("  Adding Localizer")
          languages = ('en',)
          portal.manage_addProduct['Localizer'].manage_addLocalizer(
            title='',
            languages=languages,
          )
          Localizer = portal['Localizer']
        else:
          pr("Localizer already here")
          Localizer = portal['Localizer']
          languages = Localizer.get_supported_languages()

      # translation_service                       
      if translationservice_is_present:
        if not portalhas('translation_service'):
          pr("  translation_service not found")
          try:
              portal.manage_addProduct['TranslationService'].addPlacefulTranslationService(
                id='translation_service'
              )                                        
          except:                                        
              pass                 
          else:                  
              pr("  translation_service tool added")                  
              translation_service = portal.translation_service  

          
    # portal skins
    skins = ('CPSSkins', 'cpsskins_styles', 'cpsskins_palettes', 'icons' )

    if Target == 'CPS2':
        skins = skins + ('cpsskins_cps2', )

    if Target == 'CPS3':
        skins = skins + ('cpsskins_cps3', )

    if Target == 'Plone':
        skins = skins + ('cpsskins_plone', )

    if Target == 'Plone2':
        skins = skins + ('cpsskins_plone2', )



    if Target in ['CMF', 'CPS2', 'CPS3', 'Plone', 'Plone2' ]:
        skins = skins + ('cpsskins_cmf', )

    paths = {
        'CPSSkins': 'Products/CPSSkins/skins/CPSSkins',
        'cpsskins_styles': 'Products/CPSSkins/skins/cpsskins_styles',
        'cpsskins_palettes': 'Products/CPSSkins/skins/cpsskins_palettes',
        'cpsskins_cmf': 'Products/CPSSkins/skins/cpsskins_cmf',
        'cpsskins_cps2': 'Products/CPSSkins/skins/cpsskins_cps2',
        'cpsskins_cps3': 'Products/CPSSkins/skins/cpsskins_cps3',
        'cpsskins_plone': 'Products/CPSSkins/skins/cpsskins_plone',
        'cpsskins_plone2': 'Products/CPSSkins/skins/cpsskins_plone2',
        'icons': 'Products/CPSSkins/icons',
    }

    pr_h3("Portal skins")
    for skin in skins:
        path = paths[skin]
        path = path.replace('/', os.sep)
        pr(" FS Directory View '%s'" % skin)
        if skin in skinstool.objectIds():
            dv = skinstool[skin]
            oldpath = dv.getDirPath()
            if oldpath == path:
                prok()
            else:
                pr("  Correctly installed, correcting path")
                dv.manage_properties(dirpath=path)
        else:
            skinstool.manage_addProduct['CMFCore'].manage_addDirectoryView(filepath=path, id=skin)
            pr("  Creating skin")
    allskins = skinstool.getSkinPaths()

    pr('Using %s as source skin' % SourceSkin)
    for skin_name, skin_path in allskins:
        if skin_name != SourceSkin:
            continue
        path = [x.strip() for x in skin_path.split(',')]
        path = [x for x in path if x not in skins] # strip all
        if path and path[0] == 'custom':
            path = path[:1] + list(skins) + path[1:]
        else:
            path = list(skins) + path
        npath = ', '.join(path)
        skinstool.addSkinSelection('CPSSkins', npath)

    skinstool.default_skin = 'CPSSkins'
    pr(" Setting 'CPSSkins' as default skin")

    # create portal_themes tool
    pr_h3("portal_themes tool")

    if portalhas('portal_themes') and ReinstallDefaultThemes:
        portal.manage_delObjects(['portal_themes'])

    if not portalhas('portal_themes') or ReinstallDefaultThemes:
        portal.manage_addProduct['CPSSkins'].manage_addTool('Portal Themes Tool', None)

             
    # adding portal_themes to the list of action providers
    pr("  Adding portal_themes to the list of action providers")
    actionstool = getToolByName(self, 'portal_actions')
    if 'portal_themes' in actionstool.listActionProviders():
        pr("    Already there")
    else:    
        try: 
            actionstool.addActionProvider('portal_themes')
            pr("   Done")
        except:
            pr("   Failed")

    # Importing portal themes 
    theme_container = getattr(portal, 'portal_themes')
    pr_h3("Portal themes")
    if ReinstallDefaultThemes or (theme_container.objectIds() == [] and not portalhas('themes')):

        themes_list = { 'CMF' : [ 'CMF-Plone', 'CMF-Printable' ],
                        'CPS2' : [ 'CPS2-LightSkins', 'CPS2-Plone', 'CMF-Printable' ],
                        'CPS3' : [ 'CPS3-LightSkins', 'CPS3-Autumn', 'CPS3-Default', 'CMF-Printable' ],
                        'Plone' :  [ 'CMF-Plone', 'CMF-Printable' ],
                        'Plone2' :  [ 'CMF-Plone', 'CMF-Printable' ] }

        if Target in ['CMF', 'CPS2', 'CPS3', 'Plone', 'Plone2' ]:
            theme_ids = theme_container.objectIds()
            theme_container.manage_delObjects(theme_ids)
            for theme_name in themes_list[Target]:
                pr(" Importing %s theme" % theme_name)
                zexppath = os.path.join(zexpdir, '%s.%s' % (theme_name, 'zexp'))
                try:
                    theme_container._importObjectFromFile(zexppath)
                except:
                    pr("    Could not import theme  %s" % theme_name)


    # RAM-cache for Templets
    pr_h3("Cache management")
    RAMCACHE_ID = 'cpsskins-templetcache'
    RENDER_METHOD_ID = 'cpsskins_render'
                
    custom_skin = skinstool.custom
    CPSSkins_skin = skinstool.CPSSkins
    if RENDER_METHOD_ID in custom_skin.objectIds():
        custom_skin._delObject(RENDER_METHOD_ID)
        pr("  '%s' deleted" % RENDER_METHOD_ID)
                
    if portalhas(RAMCACHE_ID):
        portal._delObject(RAMCACHE_ID)
        pr("  '%s' deleted" % RAMCACHE_ID)
                
    if EnableTempletCache:
        pr("  Configuring RAM Cache management for Templets")
        try:    
            portal.manage_addProduct['StandardCacheManagers'].manage_addRAMCacheManager(RAMCACHE_ID)
        except: 
            pass
               
        settings = { 'threshold': '100', 
                   'cleanup_interval': '500', 
                   'request_vars' : ('AUTHENTICATED_USER', ), 
                   'max_age':'1000'} 
                
        templetcache = portal[RAMCACHE_ID]
        templetcache.manage_editProps(title='Templet RAM cache', \
                    settings = settings)
        pr("    '%s' installed" % RAMCACHE_ID)
                
        pr("    Customizing '%s' method" % RENDER_METHOD_ID)
        CPSSkins_skin[RENDER_METHOD_ID].manage_doCustomize(folder_path='custom')    
        pr("    Associating '%s' to '%s'" % (RAMCACHE_ID, RENDER_METHOD_ID))
        render_method = getattr(custom_skin, RENDER_METHOD_ID, None)
        render_method.ZCacheable_setManagerId(manager_id = RAMCACHE_ID)


    # Action icons installer
    method = 'install_actionicons'
    if method in portal.objectIds():
        portal._delObject(method)

    pr('Creating install_actionicons External Method')
    install_actionicons = ExternalMethod(method,
                               'Install action icons',
                               'CPSSkins.install_actionicons',
                               'install')
    portal._setObject(method, install_actionicons)


    # Benchmark timer
    method = 'cpsskins_benchmarktimer'
    if method in portal.objectIds():
        portal._delObject(method)

    pr('Creating cpsskins_benchmarktimer External Method')
    cpsskins_benchmarktimer = ExternalMethod(method,
                               'Benchmark timer',
                               'CPSSkins.benchmarktimer',
                               'BenchmarkTimerInstance')
    portal._setObject(method, cpsskins_benchmarktimer)

    pr("</pre>")
    return '\n'.join(log)


def update(self):

    logf("START: CPSSkins update")
    log = []
    pr = log.append

    portal = self.portal_url.getPortalObject()

    skinstool = getToolByName(self, 'portal_skins')
    ttool = getToolByName(self, 'portal_types')
    actionstool = getToolByName(self, 'portal_actions')

    def pr_h3(msg, pr=pr):
        pr('<h3>%s</h3>' % msg)

    def prok(pr=pr):
        pr(" Already correctly installed")

    def portalhas(id, portal=portal):
        return id in portal.objectIds()

    pr("<pre>")
    pr("Starting CPSSkins update")
    pr("")

    # setting roles
    pr_h3("Setting roles")
    already = portal.valid_roles()
    for role in ('ThemeManager', # manage: create, modify, exports, import themes
                 ):
        if role not in already:
            portal._addRole(role)
            pr(" Add role %s" % role)
        else:
            pr(" Role %s already there" % role)


    permsthemes = {
        'Manage Themes': ('Manager', 'Owner', 'ThemeManager'),
        }
    portal_themes_id = 'portal_themes'

    pr(" Verifying permissions on the 'portal_themes' tool")
    setperms(portal[portal_themes_id], permsthemes, pr=pr)
    portal[portal_themes_id].reindexObjectSecurity()

    # portal types
    pr_h3("Portal types")

    types_in_themefolders = (
        'Area Shape',
        'Area Color',
        'Portal Box Shape',
        'Portal Box Color',
        'Font Color',
        'Font Shape',
        'Palette Color',
        'Palette Border',
        )

    types_in_pageblocks = (
        'Search Box Templet',
        'Action Box Templet',
        'Text Box Templet',
        'Image Box Templet',
        'Flash Box Templet',
        'Portal Box Templet',
        'Document Info Templet',
        'Theme Chooser Templet',
        'Language Templet',
        'Breadcrumbs Templet',
        'Portal Box Group Templet',
        'Main Content Templet',
        'Cell Sizer',
        'Cell Styler',
        'Cell Hider',
        )

    types_in_portalthemes = (
        'Page Block',
        'Theme Folder',
             )

    ptypes = {
    'CPSSkins' : ('Portal Theme', ) +
                 types_in_themefolders + 
                 types_in_pageblocks + 
                 types_in_portalthemes 
               }

    allowed_content_type = {
        'Page Block' : types_in_pageblocks,
        'Portal Theme' : types_in_portalthemes,
        'Theme Folder' : types_in_themefolders, 
       }

    ptypes_to_delete = [ 'FontShape', 'FontColor', 'Typefaces' ]
    
    
    for ptype in ptypes_to_delete:
        if ptype in ttool.objectIds():
             pr("  Obsolete type '%s' deleted" % ptype)
             ttool.manage_delObjects([ptype])


    ptypes_installed = ttool.objectIds()

    for prod in ptypes.keys():
        for ptype in ptypes[prod]:
            pr("  Type '%s'" % ptype)
            if ptype in ptypes_installed:
                ttool.manage_delObjects([ptype])
                pr("   Deleted")
                            
            ttool.manage_addTypeInformation(
                id=ptype,   
                add_meta_type='Factory-based Type Information',
                typeinfo_name=prod+': '+ptype,
                )           
            pr("   Installation")



    pr("  Installing allowed content types")
    for ptype in ('Page Block', 'Theme Folder', 'Portal Theme'):
        pr("     %s" % ptype)
        ttool[ptype].allowed_content_types = allowed_content_type[ptype]

            

    # Localizer
    pr_h3('i18n')
    mcat=None
    defaultmcat=None
    try:
       mcat = defaultmcat = getToolByName(self, 'portal_messages')
    except:
       pass

    if portalhas('Localizer'):
        pr("Localizer already here")
        Localizer = portal['Localizer']
        languages = Localizer.get_supported_languages()

        pr("")
        # Default MessageCatalog
        cpsskins_catalog_id = 'cpsskins'
        if 'default' not in Localizer.objectIds():
          Localizer.manage_addProduct['Localizer'].manage_addMessageCatalog(
          id='default',
          title='Default messages',
          languages=languages,
          )
          pr("  default MessageCatalogCreated")
          pr("")

        # CPSSkins Message Catalog
        if cpsskins_catalog_id in Localizer.objectIds():
          Localizer.manage_delObjects([cpsskins_catalog_id])
          pr(" Previous default MessageCatalog deleted for CPSSkins")
          pr("")
         
        # Adding the new message Catalog
        Localizer.manage_addProduct['Localizer'].manage_addMessageCatalog(
         id=cpsskins_catalog_id,
         title='CPSSkins messages',
         languages=languages,
         )
         
        pr("  CPSSkins MessageCatalogCreated")

        if portalhas('Localizer'):
         mcat = portal['Localizer'][cpsskins_catalog_id]
         defaultmcat = portal['Localizer']['default']

    skins = ['CPSSkins', ] 

    # portal messages
    if mcat is not None:
      # importing CPSSkins .po files
      for skin in skins:  
        pr(" Checking available languages for skin %s" % skin)
        podir = os.path.join('Products', 'CPSSkins' )
        popath = getPath(podir, 'i18n')
        if popath is None:      
            pr(" !!! Unable to find .po dir")
        else:                   
            pr("  Checking installable languages")
            langs = []          
            avail_langs = mcat.get_languages()
            pr("    Available languages: %s" % str(avail_langs))
            for file in os.listdir(popath):
                if file.endswith('.po'):
                    m = match('^.*([a-z][a-z])\.po$', file)
                    if m is None:
                        pr( '    Skipping bad file %s' % file)
                        continue
                    lang = m.group(1)
                    if lang in avail_langs:
                        lang_po_path = os.path.join(popath, file)
                        lang_file = open(lang_po_path)
                        pr("    Importing %s into '%s' locale" % (file, lang))
                        # Localizer < 1.1
                        try:
                            mcat.manage_import(lang, lang_file)
                        except:
                            pass
                        # Localizer 1.1
                        try:
                            mcat.po_import(lang, lang_file.read())
                        except:
                            pass
                    else:       
                        pr( '    Skipping not installed locale for file %s' % file)


    if defaultmcat is not None:
        # importing default .po files
        podir = os.path.join('Products', 'CPSSkins' )
        popath = getPath(podir, 'i18n')
        if popath is not None:      
            langs = []          
            avail_langs = defaultmcat.get_languages()
            for file in os.listdir(popath):
                if file.endswith('.po'):
                    m = match('^.*([a-z][a-z])\.po$', file)
                    if m is None:
                        pr( '    Skipping bad file %s' % file)
                        continue
                    lang = m.group(1)
                    if lang in avail_langs:
                        lang_po_path = os.path.join(popath, file)
                        lang_file = open(lang_po_path)
                        pr("    Importing %s into default '%s' locale" % (file, lang))
                        # Localizer < 1.1
                        try:
                            defaultmcat.manage_import(lang, lang_file)
                        except:
                            pass
                        # Localizer 1.1
                        try:
                            defaultmcat.po_import(lang, lang_file.read())
                        except:
                            pass
                    else:       
                        pr( '    Skipping not installed locale for file %s' % file)

      
        # 'cpsskins' domain for translation service
        if portalhas('translation_service'):
          translation_service = portal.translation_service
          pr (" Translation Service Tool found ")
      
          try:
              if getattr(portal['translation_service'], cpsskins_catalog_id, None) == None:
                  # translation domains
                  translation_service.manage_addDomainInfo(cpsskins_catalog_id,
                             'Localizer/'+cpsskins_catalog_id)
                  pr(" cpsskins domain set to Localizer/cpsskins")
          except:
              pass

    pr("")

    pr("</pre>")
    logf("END:  CPSSkins UPDATE")
    return '\n'.join(log)


def migrate(self):

    logf("START: CPSSkins migrate")
    log = []
    pr = log.append

    def pr_h3(msg, pr=pr):
        pr('<h3>%s</h3>' % msg)

    pr("<pre>")
    pr("Starting CPSSkins migrate")
    pr("")

    portal = self.portal_url.getPortalObject()
    theme_container = getattr(portal, 'portal_themes', None)
    if theme_container is None:
        portal.manage_addProduct['CPSSkins'].manage_addTool('Portal Themes Tool', None)
   
    if theme_container.objectIds() == []:
        pr("  migrating the 'themes' folder to 'portal_themes'")

        old_theme_container = getattr(portal, 'themes', None)
        if old_theme_container is not None:
             old_themes = old_theme_container.objectIds()
             pr("    moving the themes: %s " % str(old_themes) )
             cookie = old_theme_container.manage_copyObjects(old_themes)
             theme_container.manage_pasteObjects(cookie)

             # Leave that to the user:
             #portal.manage_delObjects(['themes'])
             #pr("    removed the 'themes' folder")

             pr("  Rebuilding all the themes. This may take some time ...")
             theme_container.rebuild()
    else:
        pr("  the 'portal_themes' folder is not empty.")

     

    pr_h3("Portal actions")
    actionstool = getToolByName(self, 'portal_actions')
    portal_actions = actionstool

    pr(" Cleaning obsolete actions from earlier versions ...")
    actiondelmap = {
        'portal_actions': ['skinconfig', 'uiconfig', 'imgconfig', 'templetconfig',
                           'lightskins_skinconfig', 'lightskins_templetconfig', 'lightskins_uiconfig',
                           'lightskins_myskinconfig', 'lightskins_mytempletconfig', 'lightskins_myuiconfig' ],
        }

    for tool, actionids in actiondelmap.items():
        actions_to_delete = []
        actions = list(portal[tool]._actions)
        for action in actions:
             if action.id in actionids:
                actions_to_delete.append(action) 
                
        for ac in actions_to_delete:
             pr(" Deleting %s : %s" %  (tool,ac.id))
             actions.remove(ac)
        
        portal[tool]._actions = actions

    pr("")

    pr("</pre>")
    logf("END:  CPSSkins MIGRATE")
    return '\n'.join(log)

