# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# YoU should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  ImageBox Templet
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent

from OFS.Image import Image, cookId

from BaseTemplet import BaseTemplet


def addImageBox(dispatcher, id, REQUEST=None, **kw):
    """Add an Image Box Templet."""

    ob = ImageBox(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Image Box Templet',
     'title': 'Image Box',
     'description': ('an image with an optional link or a caption'),
     'meta_type': 'Image Box Templet',
     'icon': 'imagebox_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addImageBox',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions': BaseTemplet._actions +
                 ( 
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_imagebox',
                  'visible': 0,
                  'permissions': (View,)
                 },
                 ),
     },
    )


class ImageBox(Image, BaseTemplet):
    """
    Image Box Templet.
    """
    meta_type = 'Image Box Templet'
    portal_type = 'Image Box Templet'

    security = ClassSecurityInfo()
    manage_options = Image.manage_options


    _properties = BaseTemplet._properties + (
        {'id': 'caption', 'type':'string', 'mode':'w', 'label':'Image caption', 'category' : 'general'},
        {'id': 'link', 'type':'string', 'mode':'w', 'label':'Link (http://, mailto: ...)', 'category' : 'general'},
        {'id': 'use_internal_link', 'type': 'boolean', 'mode': 'w', 'label': 'Use internal link?', 'category' : 'general'},
        {'id': 'internal_link', 'type': 'selection', 'mode':'w', 'label':'Internal link', 'select_variable' : 'cpsskins_listPaths', 'category' : 'general'},
        )

    def __init__(self, id, title,
                       caption = '',
                       link = '',
                       internal_link = '',
                       use_internal_link = 0,
                       file = '',
                       content_type = '',
                       precondition = '',
                       **kw) :
        apply(Image.__init__, (self, id, title, file, content_type, precondition))
        apply(BaseTemplet.__init__, (self, id), kw)
        self.caption = caption
        self.link = link
        self.internal_link = internal_link
        self.use_internal_link = use_internal_link
      

    security.declareProtected(View,'isPortalImage')
    def isPortalImage(self):
        """ Templet is portal image """
           
        return 1


InitializeClass(ImageBox)

