# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Language Templet
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent

from BaseTemplet import BaseTemplet


def addLanguage(dispatcher, id, REQUEST=None, **kw):
    """Add a Language Templet."""
    ob = Language(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Language Templet',
     'title': 'Language',
     'description': ('a language selector'),
     'meta_type': 'Language Templet',
     'icon': 'language_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addLanguage',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions': BaseTemplet._actions +
                 (
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_language',
                  'visible': 0,
                  'permissions': (View,)
                 },
                 )
     },
    )


class Language(BaseTemplet):
    """
    Language Templet.
    """
    meta_type = 'Language Templet'
    portal_type = 'Language Templet'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
        {'id': 'style', 'type': 'selection', 'mode': 'w', 'label': 'Appearance', 'select_variable': 'StyleList'},
        )

    def __init__(self, id, 
                       style = 'flags',
                       **kw):
        apply(BaseTemplet.__init__, (self, id), kw)
        self.StyleList = ['flags', 'dropdown list']
        self.style = style


InitializeClass(Language)

