# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Main Content
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent

from BaseTemplet import BaseTemplet


def addMainContent(dispatcher, id, REQUEST=None, **kw):
    """Add a Main Content Templet."""
    ob = MainContent(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Main Content Templet',
     'title': 'Main Content',
     'description': ('Main Content Templet'),
     'meta_type': 'Main Content Templet',
     'icon': 'maincontent_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addMainContent',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions':  BaseTemplet._actions +
                 ( 
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_maincontent',
                  'visible': 0,
                  'permissions': (View,)
                 },
                 ),
     },
    )


class MainContent(BaseTemplet):
    """
    Main Content Templet.
    """
    meta_type = 'Main Content Templet'
    portal_type = 'Main Content Templet'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
        )

    def __init__(self, id, 
                       **kw):
        apply(BaseTemplet.__init__, (self, id), kw)


    security.declareProtected(View,'isMainContent')
    def isMainContent(self):
        """ Templet is main content """
           
        return 1

    security.declareProtected(View,'can_delete')
    def can_delete(self):
        """ Can the templet be deleted ?"""
           
        return 0

    security.declareProtected(View,'can_toggle')
    def can_toggle(self):
        """ Can the templet be toggled (maximize / minimize)  ?"""
           
        return 0

InitializeClass(MainContent)

