# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Portal Box
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent

from BaseTemplet import BaseTemplet


def addPortalBox(dispatcher, id, REQUEST=None, **kw):
    """Add an Portal Box Templet."""
    ob = PortalBox(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Portal Box Templet',
     'title': 'Portal Box',
     'description': ('displays actions, folders, an about box, a login box, an info box, ...'),
     'meta_type': 'Portal Box Templet',
     'icon': 'portalbox_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addPortalBox',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions':  BaseTemplet._actions +
                 ( 
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_portalbox',
                  'visible': 0,
                  'permissions': (View,)
                 },
                 ),
     },
    )


class PortalBox(BaseTemplet):
    """
    Portal Box Templet.
    """
    meta_type = 'Portal Box Templet'
    portal_type = 'Portal Box Templet'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
       {'id':'title_source', 'type':'selection', 'mode':'w', 'label' : 'Portal box title source', 'select_variable': 'cpsskins_portalboxtitleList', 'category' : 'general'},
       {'id':'content', 'type':'selection', 'mode':'w', 'label' : 'Portal box content', 'select_variable': 'cpsskins_portalboxList', 'category' : 'general'},
       {'id':'show_action_icons', 'type':'boolean', 'mode':'w', 'label' : 'Show action icons', 'category' : 'actions', 'visible' : 'cpsskins_ifActionsCategory'},
       {'id':'show_docs', 'type':'boolean', 'mode':'w', 'label' : 'Show documents in folders', 'category' : 'folders', 'visible' : 'cpsskins_ifFolderCategory'},
       {'id':'level', 'type':'int', 'mode':'w', 'label' : 'Depth level', 'category' : 'folders', 'visible' : 'cpsskins_ifFolderCategory'},
       {'id':'base', 'type':'selection', 'mode':'w', 'label' : 'Hierarchy base', 'category' : 'folders', 'select_variable' : 'cpsskins_listFolderRoots', 'visible' : 'cpsskins_ifFolderCategory'},
       {'id':'base_path', 'type':'selection', 'mode':'w', 'label' : 'Base path', 'category' : 'folders', 'select_variable' : 'cpsskins_listPaths', 'visible' : 'cpsskins_ifFolderCategory'},
       {'id':'boxlayout', 'type':'selection', 'mode':'w', 'label' : 'Box layout', 'category' : 'layout', 'select_variable' : 'cpsskins_listBoxLayouts'},
       {'id': 'action_categories', 'type':'multiple selection', 'mode':'w', 'label':'Action categories', 'select_variable': 'cpsskins_listActionCategories', 'category' : 'actions', 'visible' : 'cpsskins_ifActionsCategory'},
       {'id': 'custom_action_categories', 'type':'lines', 'mode':'w', 'label':'Custom action categories', 'category' : 'actions', 'visible' : 'cpsskins_ifActionsCategory'},
       {'id': 'invisible_actions', 'type':'lines', 'mode':'w', 'label':'Invisible actions', 'category' : 'actions', 'visible' : 'cpsskins_ifActionsCategory'},
       {'id': 'orientation', 'type':'selection', 'mode':'w', 'label':'List orientation', 'select_variable': 'cpsskins_orientationList', 'category' : 'layout'},
       {'id': 'boxshape', 'type': 'selection', 'mode': 'w', 'label': 'Box shape', 'select_variable': 'cpsskins_listBoxShapes', 'category' : 'style', 'meta_type' : 'Portal Box Shape'},
       {'id': 'boxcolor', 'type': 'selection', 'mode': 'w', 'label': 'Box color', 'select_variable': 'cpsskins_listBoxColors', 'category' : 'style', 'meta_type' : 'Portal Box Color'},
       {'id': 'info', 'type': 'text', 'mode': 'w', 'label': 'Info text', 'category' : 'info', 'visible' : 'cpsskins_ifInfoCategory'},
    )

    def __init__(self, id,
                       content = 'actions', 
                       level = 0,
                       title_source = 'Templet title',
                       show_action_icons = 0,
                       show_docs = 0,
                       action_categories = ['user', 'global'],
                       custom_action_categories = [],
                       invisible_actions = ['view',],
                       base_path = '/',
                       orientation = 'vertical',
                       boxshape = 'LightSkins', 
                       boxcolor = 'ArrowBox', 
                       info = 'Info here',
                       base = [],
                       boxlayout = 'box',
                        **kw):
        apply(BaseTemplet.__init__, (self, id), kw)
        self.content = content
        self.level = level
        self.show_action_icons = show_action_icons
        self.show_docs = show_docs
        self.base_path = base_path
        self.title_source = title_source
        self.action_categories = action_categories
        self.custom_action_categories = custom_action_categories
        self.invisible_actions = invisible_actions
        self.orientation = orientation
        self.boxshape = boxshape
        self.boxcolor = boxcolor
        self.info = info
        self.base = base
        self.boxlayout = boxlayout

    security.declarePublic('isPortalBox')
    def isPortalBox(self):
        """ Templet is Portal Box """
           
        return 1


InitializeClass(PortalBox)

