# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Portal Box Group
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent

from BaseTemplet import BaseTemplet


def addPortalBoxGroup(dispatcher, id, REQUEST=None, **kw):
    """Add an Portal Box Group Templet."""
    ob = PortalBoxGroup(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Portal Box Group Templet',
     'title': 'Portal Box Group',
     'description': ('displays a group of boxes or a predefined slot'),
     'meta_type': 'Portal Box Group Templet',
     'icon': 'portalboxgroup_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addPortalBoxGroup',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions':  BaseTemplet._actions +
                 ( 
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_portalboxgroup',
                  'visible': 0,
                  'permissions': (View,)
                 },
                 ),
     },
    )


class PortalBoxGroup(BaseTemplet):
    """
    Portal Box Group Templet.
    """
    meta_type = 'Portal Box Group Templet'
    portal_type = 'Portal Box Group Templet'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
       {'id': 'vertical_padding', 'type': 'string', 'mode': 'w', 'label': 'Vertical padding', 'category' : 'layout'},
       {'id': 'box_group', 'type':'selection', 'mode':'w', 'label':'Box group', 'select_variable': 'cpsskins_listBoxSlots', 'category' : 'general'},
       {'id': 'boxshape', 'type': 'selection', 'mode': 'w', 'label': 'Box shape', 'select_variable': 'cpsskins_listBoxShapes', 'category' : 'style', 'meta_type' : 'Portal Box Shape'},
       {'id': 'boxcolor', 'type': 'selection', 'mode': 'w', 'label': 'Box color', 'select_variable': 'cpsskins_listBoxColors', 'category' : 'style', 'meta_type' : 'Portal Box Color'},
    )

    def __init__(self, id,
                       box_group = '0',
                       boxshape = 'LightSkins', 
                       boxcolor = 'Gray', 
                       vertical_padding = '0.5em',
		       folder_icon = '',
		       folder_open_icon = '',
                        **kw):
        apply(BaseTemplet.__init__, (self, id), kw)
        self.box_group = box_group
        self.boxshape = boxshape
        self.boxcolor = boxcolor
        self.vertical_padding = vertical_padding
        self.folder_icon = folder_icon
        self.folder_open_icon = folder_open_icon


    security.declarePublic('isPortalBoxGroup')
    def isPortalBoxGroup(self):
        """ Templet is portal box group """
           
        return 1


InitializeClass(PortalBoxGroup)

