# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Text Box Templet
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent

from BaseTemplet import BaseTemplet


def addTextBox(dispatcher, id, REQUEST=None, **kw):
    """Add a Text Box Templet."""
    ob = TextBox(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Text Box Templet',
     'title': 'Text Box',
     'description': ('contains text or HTML'),
     'meta_type': 'Text Box Templet',
     'icon': 'textbox_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addTextBox',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions':  BaseTemplet._actions +
                 (
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_textbox',
                  'visible': 0,
                  'permissions': (View,)
                 },
                 ),
     },
    )


class TextBox(BaseTemplet):
    """
    Text Box Templet.
    """
    meta_type = 'Text Box Templet'
    portal_type = 'Text Box Templet'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
        {'id':'text', 'type':'text', 'mode':'w', 'label':'Your text'},
        {'id':'structured_text', 'type':'boolean', 'mode':'w', 'label':'Use Structured Text?'},
        {'id':'render_html', 'type':'boolean', 'mode':'w', 'label':'Render HTML tags?'},
        )

    def __init__(self, id, 
                       text='Your text here', 
                       structured_text=0, 
                       render_html=1,
                       **kw):
        apply(BaseTemplet.__init__, (self, id), kw)
        self.text = text
        self.structured_text = structured_text
        self.render_html = render_html

InitializeClass(TextBox)

