# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Theme Chooser Templet
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent


from BaseTemplet import BaseTemplet


def addThemeChooser(dispatcher, id, REQUEST=None, **kw):
    """Add a Theme Chooser Templet."""
    ob = ThemeChooser(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Theme Chooser Templet',
     'title': 'Theme Chooser Templet',
     'description': ('A personal theme selector for users --- cookies must be enabled.'),
     'meta_type': 'Theme Chooser Templet',
     'icon': 'themechooser_templet.gif',
     'product': 'CPSSkins',
     'factory': 'addThemeChooser',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions':  BaseTemplet._actions + 
                 (
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_themechooser',
                  'visible': 0,
                  'permissions': (View,)
                 },
                 ),
     },
    )


class ThemeChooser(BaseTemplet):
    """
    Theme Chooser Templet.
    """
    meta_type = 'Theme Chooser Templet'
    portal_type = 'Theme Chooser Templet'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
        {'id':'themes', 'type':'multiple selection', 'mode':'w', 'label':'Selectable themes', 'select_variable': 'cpsskins_listGlobalThemes'},
        )

    def __init__(self, id, 
                       themes = [],
		       **kw):
        apply(BaseTemplet.__init__, (self, id), kw)
        self.themes = themes


InitializeClass(ThemeChooser)

