# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Theme Folder
"""

from Globals import InitializeClass, DTMLFile
from AccessControl import getSecurityManager, ClassSecurityInfo
from OFS.PropertyManager import PropertyManager
from OFS.Folder import Folder
from Acquisition import aq_base, aq_parent, aq_inner

from Products.CMFCore.utils import _verifyActionPermissions
from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent, ManagePortal
from Products.PortalContentFolder.PortalContentFolder import PortalContentFolder


def addThemeFolder(dispatcher, id, REQUEST=None):
    """Add a Theme Folder."""
    ob = ThemeFolder(id)
    container = dispatcher.Destination()
    container._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Theme Folder',
     'title' : 'Theme Folder',
     'description': ('A Theme Folder contain styles.'),
     'meta_type': 'Theme Folder',
     'icon': 'themefolder.gif',
     'product': 'CPSSkins',
     'factory': 'addThemeFolder',
     'immediate_view': '',
     'filter_content_types': 0,
     'global_allow': 0,
     'actions': ( {'id': 'view',
                  'name': 'View',
                  'action': 'string:${object_url}',
                  'category': 'object',
                  'permissions': (View,)},
                ),
     },
    )


class ThemeFolder(PortalContentFolder):
    """
    Class for Theme Folder.
    """

    meta_type = "Theme Folder"
    portal_type = "Theme Folder"

    manage_options = ( 
                      Folder.manage_options[0:1] +
                      Folder.manage_options[2:3] +
                      ()
                     )

    security = ClassSecurityInfo()

    _properties = (
        {'id': 'title', 'type':'string', 'mode':'w', 'label':'Title'},
      )

    def __init__(self, id, 
                       title = '',
                       **kw):

        self.id = id
        self.title = title

    security.declareProtected(View,'isThemeFolder')
    def isThemeFolder(self):
           
        return 1



InitializeClass(ThemeFolder)


