# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <mailto:jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

import sys

from Products.CMFCore import utils
from Products.CMFCore.CMFCorePermissions import AddPortalContent
from Products.CMFCore.DirectoryView import registerDirectory

from CPSSkinsInstaller import Installer, manage_addInstaller
from PortalThemesTool import PortalThemesTool

import PageBlock
import BaseTemplet
import BaseCellModifier
import BasePalette
import MainContent
import SearchBox
import Breadcrumbs
import ActionBox
import TextBox
import ImageBox
import FlashBox
import PortalBox
import Language
import DocumentInfo
import ThemeChooser
import PortalBoxGroup
import CellStyler
import CellSizer
import CellHider
import PortalTheme
import AreaColor
import AreaShape
import PortalBoxColor
import PortalBoxShape
import FontColor
import FontShape
import PaletteColor
import PaletteBorder
import ThemeFolder


this_module = sys.modules[__name__]

tools = (PortalThemesTool, )


portalthemeClasses = (PortalTheme.PortalTheme,
                      ThemeFolder.ThemeFolder,
                     )

pageblockClasses = (PageBlock.PageBlock, 
                    )

templetClasses = (
                  SearchBox.SearchBox,
                  MainContent.MainContent,
                  ActionBox.ActionBox,
                  TextBox.TextBox,
                  ImageBox.ImageBox,
                  FlashBox.FlashBox,
                  PortalBox.PortalBox,
                  DocumentInfo.DocumentInfo,
                  ThemeChooser.ThemeChooser,
                  Language.Language,
                  Breadcrumbs.Breadcrumbs,
                  PortalBoxGroup.PortalBoxGroup,
                 )

cellmodifierClasses = (
                  CellStyler.CellStyler,
                  CellSizer.CellSizer,
                  CellHider.CellHider,
                 )

styleClasses = (
                  AreaColor.AreaColor,
                  AreaShape.AreaShape,
                  PortalBoxColor.PortalBoxColor,
                  PortalBoxShape.PortalBoxShape,
                  FontColor.FontColor,
                  FontShape.FontShape,
               )
                 
paletteClasses = (
                  PaletteColor.PaletteColor,
                  PaletteBorder.PaletteBorder,
                 )

contentConstructors = (PortalTheme.addPortalTheme,
                       PageBlock.addPageBlock,
                       MainContent.addMainContent,
                       SearchBox.addSearchBox,
                       ActionBox.addActionBox,
                       TextBox.addTextBox,
                       ImageBox.addImageBox,
                       FlashBox.addFlashBox,
                       PortalBox.addPortalBox,
                       Language.addLanguage,
                       DocumentInfo.addDocumentInfo,
                       ThemeChooser.addThemeChooser,
                       Breadcrumbs.addBreadcrumbs,
                       PortalBoxGroup.addPortalBoxGroup,
                       CellStyler.addCellStyler,
                       CellSizer.addCellSizer,
                       CellHider.addCellHider,
                       AreaColor.addAreaColor,
                       AreaShape.addAreaShape,
                       PortalBoxColor.addPortalBoxColor,
                       PortalBoxShape.addPortalBoxShape,
                       FontColor.addFontColor,
                       FontShape.addFontShape,
                       PaletteColor.addPaletteColor,
                       PaletteBorder.addPaletteBorder,
                       ThemeFolder.addThemeFolder,
                       )

fti = (PortalTheme.factory_type_information +
       PageBlock.factory_type_information +
       MainContent.factory_type_information +
       SearchBox.factory_type_information +
       ActionBox.factory_type_information +
       TextBox.factory_type_information +
       ImageBox.factory_type_information +
       FlashBox.factory_type_information +
       PortalBox.factory_type_information +
       DocumentInfo.factory_type_information +
       ThemeChooser.factory_type_information +
       Language.factory_type_information +
       Breadcrumbs.factory_type_information +
       PortalBoxGroup.factory_type_information +
       CellStyler.factory_type_information +
       CellSizer.factory_type_information +
       CellHider.factory_type_information +
       AreaColor.factory_type_information +
       AreaShape.factory_type_information +
       PortalBoxColor.factory_type_information +
       PortalBoxShape.factory_type_information +
       FontShape.factory_type_information +
       FontColor.factory_type_information +
       PaletteColor.factory_type_information +
       PaletteBorder.factory_type_information +
       ThemeFolder.factory_type_information +
       ())


contentClasses = portalthemeClasses + \
                 pageblockClasses + \
                 templetClasses + \
                 cellmodifierClasses + \
                 styleClasses + \
                 paletteClasses

bases = contentClasses 

this_module = sys.modules[__name__]
z_bases = utils.initializeBasesPhase1(bases, this_module)
z_tool_bases = utils.initializeBasesPhase1(tools, this_module)

for path in ('icons', 
             'skins/CPSSkins', 
             'skins/cpsskins_styles', 
             'skins/cpsskins_palettes', 
             'skins/cpsskins_cmf', 
             'skins/cpsskins_cps2', 
             'skins/cpsskins_cps3', 
             'skins/cpsskins_plone', 
             'skins/cpsskins_plone2') :
    registerDirectory(path, globals())

def initialize(registrar):
    registrar.registerClass(
        CPSSkinsInstaller.Installer,
        constructors=(manage_addInstaller, CPSSkinsInstaller.manage_addCPSSkins,),
        )
    utils.initializeBasesPhase2(z_bases, registrar)
    utils.initializeBasesPhase2(z_tool_bases, registrar)
    utils.ToolInit(
        'Portal Themes Tool',
        tools=tools,
        product_name='CPSSkins',
        icon='draw.gif',
    ).initialize(registrar)
    utils.ContentInit(
        'CPSSkins Content',
        content_types = contentClasses,
        permission = AddPortalContent,
        extra_constructors = contentConstructors,
        fti = fti,
        ).initialize(registrar)

    utils.registerIcon(PortalTheme.PortalTheme, 'icons/portaltheme.gif', globals())
    utils.registerIcon(ThemeFolder.ThemeFolder, 'icons/themefolder.gif', globals())
    utils.registerIcon(PageBlock.PageBlock, 'icons/pageblock.gif', globals())

    utils.registerIcon(MainContent.MainContent, 'icons/maincontent_templet.gif', globals())

    utils.registerIcon(TextBox.TextBox, 'icons/textbox_templet.gif', globals())
    utils.registerIcon(ImageBox.ImageBox, 'icons/imagebox_templet.gif', globals())
    utils.registerIcon(FlashBox.FlashBox, 'icons/flashbox_templet.gif', globals())
    utils.registerIcon(Language.Language, 'icons/language_templet.gif', globals())
    utils.registerIcon(SearchBox.SearchBox, 'icons/searchbox_templet.gif', globals())
    utils.registerIcon(ActionBox.ActionBox, 'icons/actionbox_templet.gif', globals())
    utils.registerIcon(Breadcrumbs.Breadcrumbs, 'icons/breadcrumbs_templet.gif', globals())
    utils.registerIcon(DocumentInfo.DocumentInfo, 'icons/documentinfo_templet.gif', globals())
    utils.registerIcon(ThemeChooser.ThemeChooser, 'icons/documentinfo_templet.gif', globals())
    utils.registerIcon(PortalBoxGroup.PortalBoxGroup, 'icons/portalboxgroup_templet.gif', globals())
    utils.registerIcon(PortalBox.PortalBox, 'icons/portalbox_templet.gif', globals())

    utils.registerIcon(CellStyler.CellStyler, 'icons/cell_styler.gif', globals())
    utils.registerIcon(CellSizer.CellSizer, 'icons/cell_sizer.gif', globals())
    utils.registerIcon(CellHider.CellHider, 'icons/cell_hider.gif', globals())

    utils.registerIcon(AreaColor.AreaColor, 'icons/area_color.gif', globals())
    utils.registerIcon(AreaShape.AreaShape, 'icons/area_shape.gif', globals())
    utils.registerIcon(PortalBoxColor.PortalBoxColor, 'icons/box_color.gif', globals())
    utils.registerIcon(PortalBoxShape.PortalBoxShape, 'icons/box_shape.gif', globals())
    utils.registerIcon(FontColor.FontColor, 'icons/fontcolor.gif', globals())
    utils.registerIcon(FontShape.FontShape, 'icons/fontshape.gif', globals())

    utils.registerIcon(PaletteColor.PaletteColor, 'icons/palette_color.gif', globals())
    utils.registerIcon(PaletteBorder.PaletteBorder, 'icons/palette_border.gif', globals())

