# Copyright (c) 2003 Chalmers University of Technology
# Authors: Jean-Marc Orliaguet <jmo@ita.chalmers.se>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

"""
  Collapsible Menu Templet
"""

from Globals import InitializeClass
from AccessControl import ClassSecurityInfo

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent

from Products.CPSSkins.BaseTemplet import BaseTemplet


def addCollapsibleMenu(dispatcher, id, REQUEST=None, **kw):
    """Add an Collapsible Menu Templet."""
    ob = CollapsibleMenu(id, **kw)
    dispatcher._setObject(id, ob)
    if REQUEST is not None:
        url = dispatcher.DestinationURL()
        REQUEST.RESPONSE.redirect('%s/manage_main' % url)


factory_type_information = (
    {'id': 'Collapsible Menu Templet',
     'title': 'Collapsible Menu Templet',
     'description': ('Collapsible Menu Templet'),
     'meta_type': 'Collapsible Menu Templet',
     'content_icon': 'collapsiblemenu.gif',
     'product': 'CPSSkinsCollapsibleMenus',
     'factory': 'addCollapsibleMenu',
     'immediate_view': 'cpsskins_edit_form',
     'filter_content_types': 0,
     'actions':  BaseTemplet._actions +
                 (
                 {'id': 'render',
                  'name': 'Render',
                  'action': 'cpsskins_collapsiblemenu',
                  'visible': 0,
                  'permissions': (View,)
                 },
                 ),
     },
    )


class CollapsibleMenu(BaseTemplet):
    """
    Collapsible Menu Templet.
    """
    meta_type = 'Collapsible Menu Templet'
    portal_type = 'Collapsible Menu Templet'

    security = ClassSecurityInfo()

    _properties = BaseTemplet._properties + (
       {'id': 'show_docs', 'type': 'boolean', 'mode': 'w', 'label': 'Show documents', 'category' : 'general'},
       {'id': 'max_items', 'type': 'int', 'mode': 'w', 'label': 'Maximum number of items', 'category' : 'general'},
       {'id':'base', 'type':'selection', 'mode':'w', 'label' : 'Hierarchy base', 'category' : 'folders', 'select_variable' : 'cpsskins_listFolderRoots'},
       {'id':'base_path', 'type':'selection', 'mode':'w', 'label' : 'Base path', 'category' : 'folders', 'select_variable' : 'cpsskins_listPaths'},
       {'id': 'collapsiblemenu_style', 'type': 'selection', 'mode': 'w', 'label': 'Collapsible Menu Style', 'select_variable': 'cpsskins_listCollapsibleMenuStyles', 'category' : 'style'},
        )

    def __init__(self, id, 
                       show_docs = 1,
                       max_items = 10,
                       base_path = '',
                       base = '',
                       collapsiblemenu_style = '',
                       **kw):
        apply(BaseTemplet.__init__, (self, id), kw)
        self.show_docs = show_docs
        self.max_items = max_items
        self.base_path = base_path
        self.base = base
        self.collapsiblemenu_style = collapsiblemenu_style

InitializeClass(CollapsibleMenu)

